
## CATO-CLI - mutation.site.removeNetworkRange:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeNetworkRange) for documentation on this operation.

### Usage for mutation.site.removeNetworkRange:

`catocli mutation site removeNetworkRange -h`

`catocli mutation site removeNetworkRange <accountID> <json>`

`catocli mutation site removeNetworkRange 12345 "$(cat < removeNetworkRange.json)"`

`catocli mutation site removeNetworkRange 12345 '{"networkRangeId": "ID"}'`

#### Operation Arguments for mutation.site.removeNetworkRange ####
`accountId` [ID] - (required) N/A 
`networkRangeId` [ID] - (required) N/A 
